@@ -5,7 +5,7 @@ from copy import deepcopy
 from functools import lru_cache
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-import numpy as np  # type: ignore
+import numpy as np
 from OpenGL.GL import (
     GL_ARRAY_BUFFER,
     GL_DEPTH_TEST,
@@ -47,7 +47,7 @@ from payton.math.functions import (
     vector_transform,
 )
 from payton.math.geometry import raycast_sphere_intersect
-from payton.math.matrix import Matrix, IDENTITY_MATRIX
+from payton.math.matrix import IDENTITY_MATRIX, Matrix
 from payton.math.vector import Vector2D, Vector3D
 from payton.scene.material import DEFAULT, NO_INDICE, NO_VERTEX_ARRAY, POINTS, SOLID, WIREFRAME, Material
 from payton.scene.shader import DEFAULT_SHADER, PARTICLE_SHADER, Shader
@@ -57,9 +57,9 @@ from payton.scene.types import IList, VList
 class Object:
     def __init__(
         self,
-        name="",
-        visible=True,
-        track_motion=False,
+        name: str = "",
+        visible: bool = True,
+        track_motion: bool = False,
         **kwargs: Dict[str, Any],
     ) -> None:
         """Initialize the object
@@ -109,8 +109,8 @@ class Object:
         # and if we fill all of it, we resize it.
         self._buffer_size: float = 500 * 12
         self._t_buffer_size: float = 500 * 8
-        self._model_matrix: np.ndarray = []  # Model matrix.
-        self._model_matrix_fortran: np.ndarray = []  # Model matrix as fortran
+        self._model_matrix: np.ndarray = np.array([], dtype=np.float64)  # Model matrix.
+        self._model_matrix_fortran: np.ndarray = np.array([], dtype=np.float64)  # Model matrix as fortran
         # Check if buffer size allocated for the object has changed.
         self._buffer_size_changed: bool = True
         self._t_buffer_size_changed: bool = True
@@ -125,7 +125,7 @@ class Object:
         if not isinstance(self, Line):
             # _motion_path_line is used to display the motion path in scene
             self._motion_path_line = Line()
-        self._previous_matrix: Union[np.ndarray, None] = None
+        self._previous_matrix: Optional[Union[np.ndarray, List[float]]] = None
 
         # For raycast tests - bounding radius is the radius of the bounding
         # sphere.
@@ -187,7 +187,7 @@ class Object:
         return self.matrix[1][:3]
 
     @direction.setter
-    def direction(self, v: Vector3D):
+    def direction(self, v: Vector3D) -> None:
         """Set the direction towards a given vector.
 
         Note: This is a unit vector and be sure to provide a unit vector!
@@ -209,7 +209,7 @@ class Object:
         self._to_absolute.cache_clear()
         self._absolute_vertices = None
 
-    def direct_to(self, v: Vector3D):
+    def direct_to(self, v: Vector3D) -> None:
         """Direct object to given coordinates in space.
 
         Keyword arguments:
@@ -412,7 +412,7 @@ class Object:
         self._motion_path.append(deepcopy(self.matrix))
         # Add the matrix position to motion math line for visualisation
         if self._motion_path_line is not None:
-            self._motion_path_line.append([[self.matrix[3][0], self.matrix[3][1], self.matrix[3][2], 1.0]])
+            self._motion_path_line.append([[self.matrix[3][0], self.matrix[3][1], self.matrix[3][2]]])
 
         # Python trick here! need to .copy or it will pass reference.
         self._previous_matrix = self.matrix[3]
@@ -446,8 +446,9 @@ class Object:
         if self._no_missing_vao:
             return False
         result = any(
-            [material._vao == NO_VERTEX_ARRAY and len(material._indices) > 1 for material in self.materials.values()]
+            material._vao == NO_VERTEX_ARRAY and len(material._indices) > 1 for material in self.materials.values()
         )
+
         if not result:
             self._no_missing_vao = True
         return result
@@ -500,7 +501,7 @@ class Object:
             glDisable(GL_DEPTH_TEST)
 
         for material in self.materials.values():
-            if not material.display == SOLID and shader._depth_shader:
+            if material.display != SOLID and shader._depth_shader:
                 continue
 
             material.render(
@@ -546,7 +547,7 @@ class Object:
         for child in self.children:
             self.children[child].render(lit, shader, self._model_matrix)
 
-    def set_position(self, x: float, y: float, z: float):
+    def set_position(self, x: float, y: float, z: float) -> None:
         """Set the position of the object
 
         Keyword arguments:
@@ -563,7 +564,7 @@ class Object:
         return self.matrix[3][:3]
 
     @position.setter
-    def position(self, pos: Union[Vector3D, list, tuple]) -> None:
+    def position(self, pos: Vector3D) -> None:
         """Set the position of the object by a given Vector
 
         In this context, the definition of the position is extended to
@@ -633,13 +634,8 @@ class Object:
         for mat in self.materials.values():
             mat.display = d
 
-        if d == POINTS:
-            self.shader = PARTICLE_SHADER
-            self.refresh()
-        else:
-            self.shader = DEFAULT_SHADER
-            self.refresh()
-
+        self.shader = PARTICLE_SHADER if d == POINTS else DEFAULT_SHADER
+        self.refresh()
         for child in self.children.values():
             child.toggle_wireframe()
 
@@ -899,7 +895,7 @@ class Line(Object):
             self.material._indices.append([i, i + 1])
             self._indices = self.material._indices
 
-        for i in range(self._vertex_count):
+        for _ in range(self._vertex_count):
             self._normals.append([0, 0, 0])
             self._texcoords.append([0, 0])
         self._needs_update = True
