@@ -4,7 +4,7 @@ import logging
 import time
 from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar
 
-import numpy as np  # type: ignore
+import numpy as np
 import sdl2
 from OpenGL.GL import (
     GL_CLAMP_TO_EDGE,
@@ -63,6 +63,7 @@ from payton.math.geometry import (
     raycast_triangle_intersect,
 )
 from payton.math.vector import Vector3D
+from payton.scene.camera import Camera
 from payton.scene.clock import Clock
 from payton.scene.collision import CollisionTest
 from payton.scene.controller import Controller, GUIController, SceneController
@@ -71,7 +72,6 @@ from payton.scene.grid import Grid
 from payton.scene.gui import Hud, Shape2D
 from payton.scene.gui.help import help_win
 from payton.scene.light import Light
-from payton.scene.camera import Camera
 from payton.scene.receiver import Receiver
 from payton.scene.shader import (
     DEFAULT_SHADER,
@@ -193,7 +193,7 @@ class Scene(Receiver):
         return self._shadow_samples
 
     @shadow_samples.setter
-    def shadow_samples(self, samples: int):
+    def shadow_samples(self, samples: int) -> None:
         """Set shadow samples
 
         Keyword arguments:
@@ -209,7 +209,7 @@ class Scene(Receiver):
         return self._shadow_quality
 
     @shadow_quality.setter
-    def shadow_quality(self, quality: int):
+    def shadow_quality(self, quality: int) -> None:
         """Set shadow quality
 
         Shadow quality is simply the resolution of shadow texture in pixels.
@@ -226,7 +226,7 @@ class Scene(Receiver):
         plane_point: Vector3D,
         plane_normal: Vector3D,
         callback: Callable[[Vector3D], Any],
-    ):
+    ) -> None:
         """Add a click plane to the scene.
 
         Click planes are infinite 2D planes that can grep and react to clicks.
@@ -253,7 +253,7 @@ class Scene(Receiver):
                 continue
             click_plane[2](hit[:3])
 
-    def _render_3d_scene(self, shadow_round=False, shader=DEFAULT_SHADER) -> None:
+    def _render_3d_scene(self, shadow_round: bool = False, shader: str = DEFAULT_SHADER) -> None:
         """Render the 3D Scene
 
         Keyword arguments:
@@ -280,25 +280,24 @@ class Scene(Receiver):
         _shader.set_matrix4x4_np("projection", proj)
         light_array = [light.position for light in self.lights]
         lcolor_array = [light.color for light in self.lights]
-        light_array = np.array(light_array, dtype=np.float32)
-        lcolor_array = np.array(lcolor_array, dtype=np.float32)
-        _shader.set_vector3_array_np("light_pos", light_array, light_count)
+        light_array_np = np.array(light_array, dtype=np.float32)
+        lcolor_array_np = np.array(lcolor_array, dtype=np.float32)
+        _shader.set_vector3_array_np("light_pos", light_array_np, light_count)
 
         if not shadow_round:
             _shader.set_int("LIGHT_COUNT", light_count)
             _shader.set_int("samples", self._shadow_samples)
-            _shader.set_vector3_array_np("light_color", lcolor_array, light_count)
+            _shader.set_vector3_array_np("light_color", lcolor_array_np, light_count)
         if self.shadow_quality > 0 and not shadow_round:
             _shader.set_int("shadow_enabled", 1)
         if shadow_round:
             shadow_matrices = self.lights[0].shadow_matrices
             for i, mat in enumerate(shadow_matrices):
                 _shader.set_matrix4x4_np("shadowMatrices[{}]".format(i), mat)
-        else:
-            if self.depth_map > -1:
-                glActiveTexture(GL_TEXTURE1)
-                glBindTexture(GL_TEXTURE_CUBE_MAP, self.depth_map)
-                _shader.set_int("depthMap", 1)
+        elif self.depth_map > -1:
+            glActiveTexture(GL_TEXTURE1)
+            glBindTexture(GL_TEXTURE_CUBE_MAP, self.depth_map)
+            _shader.set_int("depthMap", 1)
 
         if not shadow_round and shader == DEFAULT_SHADER:
             self.grid.render(lit, self.shaders[DEFAULT_SHADER])
@@ -318,7 +317,7 @@ class Scene(Receiver):
         glDepthFunc(GL_LESS)
 
         glClearColor(0.1, 0.1, 0.1, 1.0)
-        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)  # type: ignore
+        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
 
         if self.shadow_quality > 0:
             glViewport(0, 0, self._shadow_quality, self._shadow_quality)
@@ -331,7 +330,7 @@ class Scene(Receiver):
 
         # Render background
         glViewport(0, 0, self.window_width, self.window_height)
-        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)  # type: ignore
+        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
         self.background.render()
         glEnable(GL_DEPTH_TEST)
         glDepthFunc(GL_LESS)
@@ -471,7 +470,7 @@ class Scene(Receiver):
         c = Clock(period, callback)
         self.clocks[name] = c
 
-    def _clear_context(self):
+    def _clear_context(self) -> None:
         for shader in self.shaders.values():
             shader.program = -1
         self.background._shader.program = -1
@@ -491,18 +490,17 @@ class Scene(Receiver):
 
         self.clocks = new_clocks
 
-    def to_dict(self):
+    def to_dict(self) -> Dict[str, Any]:
         """Convert everything inside the Scene to Dictionary
 
         This method is better to be called outside the render cycle as it can be
         very costly.
         """
-        result = {
+        return {
             "objects": {name: self.objects[name].to_dict() for name in self.objects},
             "lights": [light.to_dict() for light in self.lights],
             "cameras": [camera.to_dict() for camera in self.cameras],
         }
-        return result
 
     def raycast_intersect(
         self,
@@ -528,9 +526,8 @@ class Scene(Receiver):
         dist_best = -1.0
         hit_obj = None
         for obj in self.objects.values():
-            if exempt_objects is not None:
-                if obj in exempt_objects:
-                    continue
+            if exempt_objects is not None and obj in exempt_objects:
+                continue
             box_hit = raycast_box_intersect(start, direction, obj.bounding_box[0], obj.bounding_box[1])
             if box_hit is None:
                 continue
@@ -542,9 +539,10 @@ class Scene(Receiver):
                     hit_obj = obj
                     continue
             for p1, p2, p3 in zip(*[iter(obj.absolute_vertices())] * 3):
-                ip, _ = raycast_triangle_intersect(start, direction, p1, p2, p3)
-                if ip is None:
+                ip_np, _ = raycast_triangle_intersect(start, direction, p1, p2, p3)
+                if ip_np is None:
                     continue
+                ip = ip_np.tolist()
                 dist = distance_native(ip, start)
                 if dist_best == -1.0 or dist < dist_best:
                     dist_best = dist
@@ -570,7 +568,7 @@ class Scene(Receiver):
             int(self.window_width),
             int(self.window_height),
             sdl2.SDL_WINDOW_OPENGL | sdl2.SDL_WINDOW_RESIZABLE,
-        )  # type: ignore
+        )
 
         if not self.window:
             return -1
@@ -680,7 +678,7 @@ Payton requires at least OpenGL 3.3 support and above."""
         self._clear_context()
         return 0
 
-    def terminate(self):
+    def terminate(self) -> None:
         self.running = False
         for clock in self.clocks:
             logging.debug(f"Kill clock [{clock}]")
@@ -717,7 +715,7 @@ class Background:
         self._vao = None
         self.visible = True
 
-    def set_time(self, hour: int, minute: int):
+    def set_time(self, hour: int, minute: int) -> None:
         """Background can mimic a background color based on the time of the date
         It is not accurate but at least gives a small impression
 
@@ -725,8 +723,8 @@ class Background:
         hour -- Hour as integer (24 hour format)
         minute -- Minute as integer
         """
-        hour = hour % 24
-        minute = minute % 60
+        hour %= 24
+        minute %= 60
         color_scheme = {
             (0, 3): [[24 / 255, 24 / 255, 48 / 255, 1.0], [24 / 255, 48 / 255, 72 / 255, 1.0]],
             (3, 9): [[24 / 255, 48 / 255, 72 / 255, 1.0], [96 / 255, 168 / 255, 192 / 255, 1.0]],
